@@ -7,10 +7,14 @@ use base 'HTML::Tested::Value::DropDown';
 sub value_to_string {
 	my ($self, $name, $val) = @_;
 	my $res = $self->SUPER::value_to_string($name, $val);
+	my $href = $self->options->{href} || "?$name=";
 	return <<ENDS
 <form>$res</form>
 <script>
-document.getElementById("$name").onchange = function() { this.form.submit(); };
+document.getElementById("$name").onchange = function() {
+	document.location.href = "$href" + this.options[
+		this.selectedIndex ].value;
+};
 </script>
 ENDS
 }
